<?php

namespace App\Controller;

// Importations
use App\Entity\Degree;
use App\Form\DegreeType;
use App\Repository\DegreeRepository;
use Doctrine\ORM\EntityManagerInterface;
use Symfony\Bundle\FrameworkBundle\Controller\AbstractController;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Routing\Annotation\Route;

#[Route('/degree')]
final class DegreeController extends AbstractController
{
    #[Route(name: 'app_degree_index', methods: ['GET'])]
    public function index(DegreeRepository $degreeRepository): Response
    {
        $this->denyAccessUnlessGranted('ROLE_ADMIN');
        // Récupère tous les diplômes
        $degrees = $degreeRepository->findAll();

        // Affiche la vue avec les diplômes
        return $this->render('degree/index.html.twig', [
            'degrees' => $degrees,
        ]);
    }

    #[Route('/new', name: 'app_degree_new', methods: ['GET', 'POST'])]
    public function new(Request $request, EntityManagerInterface $entityManager): Response
    {
        $degree = new Degree();
        $form = $this->createForm(DegreeType::class, $degree);
        $form->handleRequest($request);

        if ($form->isSubmitted() && $form->isValid()) {
            // Sauvegarde le nouveau diplôme dans la base
            $entityManager->persist($degree);
            $entityManager->flush();

            // Redirection vers la liste des diplômes
            return $this->redirectToRoute('app_degree_index', [], Response::HTTP_SEE_OTHER);
        }

        return $this->render('degree/new.html.twig', [
            'degree' => $degree,
            'form' => $form->createView(),
        ]);
    }

    #[Route('/{id}', name: 'app_degree_show', methods: ['GET'])]
    public function show(Degree $degree): Response
    {
        // Affiche les détails d'un diplôme spécifique
        return $this->render('degree/show.html.twig', [
            'degree' => $degree,
        ]);
    }

    #[Route('/{id}/edit', name: 'app_degree_edit', methods: ['GET', 'POST'])]
    public function edit(Request $request, Degree $degree, EntityManagerInterface $entityManager): Response
    {
        // Création du formulaire de modification
        $form = $this->createForm(DegreeType::class, $degree);
        $form->handleRequest($request);

        if ($form->isSubmitted() && $form->isValid()) {
            // Sauvegarde des modifications dans la base
            $entityManager->flush();

            // Redirection vers la liste des diplômes après modification
            return $this->redirectToRoute('app_degree_index', [], Response::HTTP_SEE_OTHER);
        }

        return $this->render('degree/edit.html.twig', [
            'degree' => $degree,
            'form' => $form->createView(),
        ]);
    }

    #[Route('/{id}', name: 'app_degree_delete', methods: ['POST'])]
    public function delete(Request $request, Degree $degree, EntityManagerInterface $entityManager): Response
    {
        if ($this->isCsrfTokenValid('delete' . $degree->getId(), $request->request->get('_token'))) {
            $entityManager->remove($degree);
            $entityManager->flush();
        }

        return $this->redirectToRoute('app_degree_index', [], Response::HTTP_SEE_OTHER);
    }


}

